@@ -22,13 +22,13 @@ normalizeData <-function(dataInput, dataInputName = NA)
 
     #timeMin <- min(dataInput$time)
     timeData <- dataInput$time
-    timeRange <- max(timeData)
+    timeRange <- max(timeData,na.rm = T)
     timeData <- timeData / timeRange
 
-    intensityMin <- min(dataInput$intensity)
-    intensityMax <- max(dataInput$intensity)
+    intensityMin <- min(dataInput$intensity,na.rm = T)
+    intensityMax <- max(dataInput$intensity,na.rm = T)
     intensityData <- dataInput$intensity - intensityMin
-    intensityRange <- max(intensityData)
+    intensityRange <- max(intensityData,na.rm = T)
     intensityData <- intensityData / intensityRange
 
     dataOutput <- data.frame(time = timeData, intensity = intensityData)
